import { CommentReportResponse, CommentResponse, CreateComment, CreateCommentLike, CreateCommentReport, DeleteComment, EditComment, GetComments, GetCommentsResponse, ListCommentReports, ListCommentReportsResponse, RemoveComment, ResolveCommentReport, SaveComment } from "./interfaces/api/comment";
import { AddModToCommunity, AddModToCommunityResponse, BanFromCommunity, BanFromCommunityResponse, BlockCommunity, BlockCommunityResponse, CommunityResponse, CreateCommunity, DeleteCommunity, EditCommunity, FollowCommunity, GetCommunity, GetCommunityResponse, ListCommunities, ListCommunitiesResponse, RemoveCommunity, TransferCommunity } from "./interfaces/api/community";
import { AddAdmin, AddAdminResponse, BannedPersonsResponse, BanPerson, BanPersonResponse, BlockPerson, BlockPersonResponse, ChangePassword, CreatePrivateMessage, DeleteAccount, DeleteAccountResponse, DeletePrivateMessage, EditPrivateMessage, GetBannedPersons, GetCaptchaResponse, GetPersonDetails, GetPersonDetailsResponse, GetPersonMentions, GetPersonMentionsResponse, GetPrivateMessages, GetReplies, GetRepliesResponse, GetReportCount, GetReportCountResponse, GetUnreadCount, GetUnreadCountResponse, Login, LoginResponse, MarkAllAsRead, MarkCommentReplyAsRead, MarkPersonMentionAsRead, MarkPrivateMessageAsRead, PasswordChange, PasswordReset, PasswordResetResponse, PersonMentionResponse, PrivateMessageResponse, PrivateMessagesResponse, Register, SaveUserSettings, VerifyEmail, VerifyEmailResponse } from "./interfaces/api/person";
import { CreatePost, CreatePostLike, CreatePostReport, DeletePost, EditPost, GetPost, GetPostResponse, GetPosts, GetPostsResponse, GetSiteMetadata, GetSiteMetadataResponse, ListPostReports, ListPostReportsResponse, LockPost, MarkPostAsRead, PostReportResponse, PostResponse, RemovePost, ResolvePostReport, SavePost, StickyPost } from "./interfaces/api/post";
import { ApproveRegistrationApplication, CreateSite, EditSite, GetModlog, GetModlogResponse, GetSite, GetSiteResponse, GetUnreadRegistrationApplicationCount, GetUnreadRegistrationApplicationCountResponse, LeaveAdmin, ListRegistrationApplications, ListRegistrationApplicationsResponse, PurgeComment, PurgeCommunity, PurgeItemResponse, PurgePerson, PurgePost, RegistrationApplicationResponse, ResolveObject, ResolveObjectResponse, Search, SearchResponse, SiteResponse } from "./interfaces/api/site";
export declare class LemmyHttpError extends Error {
    response: Response;
}
/**
 * Helps build lemmy HTTP requests.
 */
export declare class LemmyHttp {
    private apiUrl;
    private headers;
    /**
     * Generates a new instance of LemmyHttp.
     * @param baseUrl the base url, without the vX version: https://lemmy.ml -> goes to https://lemmy.ml/api/vX
     * @param headers optional headers. Should contain `x-real-ip` and `x-forwarded-for` .
     */
    constructor(baseUrl: string, headers?: {
        [key: string]: string;
    });
    /**
     * Gets the site, and your user data.
     *
     * `HTTP.GET /site`
     */
    getSite(form: GetSite): Promise<GetSiteResponse>;
    /**
     * Create your site.
     *
     * `HTTP.POST /site`
     */
    createSite(form: CreateSite): Promise<SiteResponse>;
    /**
     * Edit your site.
     *
     * `HTTP.PUT /site`
     */
    editSite(form: EditSite): Promise<SiteResponse>;
    /**
     * Leave the Site admins.
     *
     * `HTTP.POST /user/leave_admin`
     */
    leaveAdmin(form: LeaveAdmin): Promise<GetSiteResponse>;
    /**
     * Get the modlog.
     *
     * `HTTP.GET /modlog`
     */
    getModlog(form: GetModlog): Promise<GetModlogResponse>;
    /**
     * Search lemmy.
     *
     * `HTTP.GET /search`
     */
    search(form: Search): Promise<SearchResponse>;
    /**
     * Fetch a non-local / federated object.
     *
     * `HTTP.GET /resolve_object`
     */
    resolveObject(form: ResolveObject): Promise<ResolveObjectResponse>;
    /**
     * Create a new community.
     *
     * `HTTP.POST /community`
     */
    createCommunity(form: CreateCommunity): Promise<CommunityResponse>;
    /**
     * Get / fetch a community.
     *
     * `HTTP.GET /community`
     */
    getCommunity(form: GetCommunity): Promise<GetCommunityResponse>;
    /**
     * Edit a community.
     *
     * `HTTP.PUT /community`
     */
    editCommunity(form: EditCommunity): Promise<CommunityResponse>;
    /**
     * List communities, with various filters.
     *
     * `HTTP.GET /community/list`
     */
    listCommunities(form: ListCommunities): Promise<ListCommunitiesResponse>;
    /**
     * Follow / subscribe to a community.
     *
     * `HTTP.POST /community/follow`
     */
    followCommunity(form: FollowCommunity): Promise<CommunityResponse>;
    /**
     * Block a community.
     *
     * `HTTP.POST /community/block`
     */
    blockCommunity(form: BlockCommunity): Promise<BlockCommunityResponse>;
    /**
     * Delete a community.
     *
     * `HTTP.POST /community/delete`
     */
    deleteCommunity(form: DeleteCommunity): Promise<CommunityResponse>;
    /**
     * A moderator remove for a community.
     *
     * `HTTP.POST /community/remove`
     */
    removeCommunity(form: RemoveCommunity): Promise<CommunityResponse>;
    /**
     * Transfer your community to an existing moderator.
     *
     * `HTTP.POST /community/transfer`
     */
    transferCommunity(form: TransferCommunity): Promise<GetCommunityResponse>;
    /**
     * Ban a user from a community.
     *
     * `HTTP.POST /community/ban_user`
     */
    banFromCommunity(form: BanFromCommunity): Promise<BanFromCommunityResponse>;
    /**
     * Add a moderator to your community.
     *
     * `HTTP.POST /community/mod`
     */
    addModToCommunity(form: AddModToCommunity): Promise<AddModToCommunityResponse>;
    /**
     * Create a post.
     *
     * `HTTP.POST /post`
     */
    createPost(form: CreatePost): Promise<PostResponse>;
    /**
     * Get / fetch a post.
     *
     * `HTTP.GET /post`
     */
    getPost(form: GetPost): Promise<GetPostResponse>;
    /**
     * Edit a post.
     *
     * `HTTP.PUT /post`
     */
    editPost(form: EditPost): Promise<PostResponse>;
    /**
     * Delete a post.
     *
     * `HTTP.POST /post/delete`
     */
    deletePost(form: DeletePost): Promise<PostResponse>;
    /**
     * A moderator remove for a post.
     *
     * `HTTP.POST /post/remove`
     */
    removePost(form: RemovePost): Promise<PostResponse>;
    /**
     * Mark a post as read.
     *
     * `HTTP.POST /post/mark_as_read`
     */
    markPostAsRead(form: MarkPostAsRead): Promise<PostResponse>;
    /**
     * A moderator can lock a post ( IE disable new comments ).
     *
     * `HTTP.POST /post/lock`
     */
    lockPost(form: LockPost): Promise<PostResponse>;
    /**
     * A moderator can sticky a post ( IE stick it to the top of a community ).
     *
     * `HTTP.POST /post/sticky`
     */
    stickyPost(form: StickyPost): Promise<PostResponse>;
    /**
     * Get / fetch posts, with various filters.
     *
     * `HTTP.GET /post/list`
     */
    getPosts(form: GetPosts): Promise<GetPostsResponse>;
    /**
     * Like / vote on a post.
     *
     * `HTTP.POST /post/like`
     */
    likePost(form: CreatePostLike): Promise<PostResponse>;
    /**
     * Save a post.
     *
     * `HTTP.PUT /post/save`
     */
    savePost(form: SavePost): Promise<PostResponse>;
    /**
     * Report a post.
     *
     * `HTTP.POST /post/report`
     */
    createPostReport(form: CreatePostReport): Promise<PostReportResponse>;
    /**
     * Resolve a post report. Only a mod can do this.
     *
     * `HTTP.PUT /post/report/resolve`
     */
    resolvePostReport(form: ResolvePostReport): Promise<PostReportResponse>;
    /**
     * List post reports.
     *
     * `HTTP.GET /post/report/list`
     */
    listPostReports(form: ListPostReports): Promise<ListPostReportsResponse>;
    /**
     * Fetch metadata for any given site.
     *
     * `HTTP.GET /post/site_metadata`
     */
    getSiteMetadata(form: GetSiteMetadata): Promise<GetSiteMetadataResponse>;
    /**
     * Create a comment.
     *
     * `HTTP.POST /comment`
     */
    createComment(form: CreateComment): Promise<CommentResponse>;
    /**
     * Edit a comment.
     *
     * `HTTP.PUT /comment`
     */
    editComment(form: EditComment): Promise<CommentResponse>;
    /**
     * Delete a comment.
     *
     * `HTTP.POST /comment/delete`
     */
    deleteComment(form: DeleteComment): Promise<CommentResponse>;
    /**
     * A moderator remove for a comment.
     *
     * `HTTP.POST /comment/remove`
     */
    removeComment(form: RemoveComment): Promise<CommentResponse>;
    /**
     * Mark a comment as read.
     *
     * `HTTP.POST /comment/mark_as_read`
     */
    markCommentReplyAsRead(form: MarkCommentReplyAsRead): Promise<CommentResponse>;
    /**
     * Like / vote on a comment.
     *
     * `HTTP.POST /comment/like`
     */
    likeComment(form: CreateCommentLike): Promise<CommentResponse>;
    /**
     * Save a comment.
     *
     * `HTTP.PUT /comment/save`
     */
    saveComment(form: SaveComment): Promise<CommentResponse>;
    /**
     * Get / fetch comments.
     *
     * `HTTP.GET /comment/list`
     */
    getComments(form: GetComments): Promise<GetCommentsResponse>;
    /**
     * Report a comment.
     *
     * `HTTP.POST /comment/report`
     */
    createCommentReport(form: CreateCommentReport): Promise<CommentReportResponse>;
    /**
     * Resolve a comment report. Only a mod can do this.
     *
     * `HTTP.PUT /comment/report/resolve`
     */
    resolveCommentReport(form: ResolveCommentReport): Promise<CommentReportResponse>;
    /**
     * List comment reports.
     *
     * `HTTP.GET /comment/report/list`
     */
    listCommentReports(form: ListCommentReports): Promise<ListCommentReportsResponse>;
    /**
     * Get / fetch private messages.
     *
     * `HTTP.GET /private_message/list`
     */
    getPrivateMessages(form: GetPrivateMessages): Promise<PrivateMessagesResponse>;
    /**
     * Create a private message.
     *
     * `HTTP.POST /private_message`
     */
    createPrivateMessage(form: CreatePrivateMessage): Promise<PrivateMessageResponse>;
    /**
     * Edit a private message.
     *
     * `HTTP.PUT /private_message`
     */
    editPrivateMessage(form: EditPrivateMessage): Promise<PrivateMessageResponse>;
    /**
     * Delete a private message.
     *
     * `HTTP.POST /private_message/delete`
     */
    deletePrivateMessage(form: DeletePrivateMessage): Promise<PrivateMessageResponse>;
    /**
     * Mark a private message as read.
     *
     * `HTTP.POST /private_message/mark_as_read`
     */
    markPrivateMessageAsRead(form: MarkPrivateMessageAsRead): Promise<PrivateMessageResponse>;
    /**
     * Register a new user.
     *
     * `HTTP.POST /user/register`
     */
    register(form: Register): Promise<LoginResponse>;
    /**
     * Log into lemmy.
     *
     * `HTTP.POST /user/login`
     */
    login(form: Login): Promise<LoginResponse>;
    /**
     * Get the details for a person.
     *
     * `HTTP.GET /user`
     */
    getPersonDetails(form: GetPersonDetails): Promise<GetPersonDetailsResponse>;
    /**
     * Get mentions for your user.
     *
     * `HTTP.GET /user/mention`
     */
    getPersonMentions(form: GetPersonMentions): Promise<GetPersonMentionsResponse>;
    /**
     * Mark a person mention as read.
     *
     * `HTTP.POST /user/mention/mark_as_read`
     */
    markPersonMentionAsRead(form: MarkPersonMentionAsRead): Promise<PersonMentionResponse>;
    /**
     * Get comment replies.
     *
     * `HTTP.GET /user/replies`
     */
    getReplies(form: GetReplies): Promise<GetRepliesResponse>;
    /**
     * Ban a person from your site.
     *
     * `HTTP.POST /user/ban`
     */
    banPerson(form: BanPerson): Promise<BanPersonResponse>;
    /**
     * Get a list of banned users
     *
     * `HTTP.GET /user/banned`
     */
    getBannedPersons(form: GetBannedPersons): Promise<BannedPersonsResponse>;
    /**
     * Block a person.
     *
     * `HTTP.POST /user/block`
     */
    blockPerson(form: BlockPerson): Promise<BlockPersonResponse>;
    /**
     * Fetch a Captcha.
     *
     * `HTTP.GET /user/get_captcha`
     */
    getCaptcha(): Promise<GetCaptchaResponse>;
    /**
     * Delete your account.
     *
     * `HTTP.POST /user/delete_account`
     */
    deleteAccount(form: DeleteAccount): Promise<DeleteAccountResponse>;
    /**
     * Reset your password.
     *
     * `HTTP.POST /user/password_reset`
     */
    passwordReset(form: PasswordReset): Promise<PasswordResetResponse>;
    /**
     * Change your password from an email / token based reset.
     *
     * `HTTP.POST /user/password_change`
     */
    passwordChange(form: PasswordChange): Promise<LoginResponse>;
    /**
     * Mark all replies as read.
     *
     * `HTTP.POST /user/mark_all_as_read`
     */
    markAllAsRead(form: MarkAllAsRead): Promise<GetRepliesResponse>;
    /**
     * Save your user settings.
     *
     * `HTTP.PUT /user/save_user_settings`
     */
    saveUserSettings(form: SaveUserSettings): Promise<LoginResponse>;
    /**
     * Change your user password.
     *
     * `HTTP.PUT /user/change_password`
     */
    changePassword(form: ChangePassword): Promise<LoginResponse>;
    /**
     * Get counts for your reports
     *
     * `HTTP.GET /user/report_count`
     */
    getReportCount(form: GetReportCount): Promise<GetReportCountResponse>;
    /**
     * Get your unread counts
     *
     * `HTTP.GET /user/unread_count`
     */
    getUnreadCount(form: GetUnreadCount): Promise<GetUnreadCountResponse>;
    /**
     * Verify your email
     *
     * `HTTP.POST /user/verify_email`
     */
    verifyEmail(form: VerifyEmail): Promise<VerifyEmailResponse>;
    /**
     * Add an admin to your site.
     *
     * `HTTP.POST /admin/add`
     */
    addAdmin(form: AddAdmin): Promise<AddAdminResponse>;
    /**
     * Get the unread registration applications count.
     *
     * `HTTP.GET /admin/registration_application/count`
     */
    getUnreadRegistrationApplicationCount(form: GetUnreadRegistrationApplicationCount): Promise<GetUnreadRegistrationApplicationCountResponse>;
    /**
     * List the registration applications.
     *
     * `HTTP.GET /admin/registration_application/list`
     */
    listRegistrationApplications(form: ListRegistrationApplications): Promise<ListRegistrationApplicationsResponse>;
    /**
     * Approve a registration application
     *
     * `HTTP.PUT /admin/registration_application/approve`
     */
    approveRegistrationApplication(form: ApproveRegistrationApplication): Promise<RegistrationApplicationResponse>;
    /**
     * Purge / Delete a person from the database.
     *
     * `HTTP.POST /admin/purge/person`
     */
    purgePerson(form: PurgePerson): Promise<PurgeItemResponse>;
    /**
     * Purge / Delete a community from the database.
     *
     * `HTTP.POST /admin/purge/community`
     */
    purgeCommunity(form: PurgeCommunity): Promise<PurgeItemResponse>;
    /**
     * Purge / Delete a post from the database.
     *
     * `HTTP.POST /admin/purge/post`
     */
    purgePost(form: PurgePost): Promise<PurgeItemResponse>;
    /**
     * Purge / Delete a comment from the database.
     *
     * `HTTP.POST /admin/purge/comment`
     */
    purgeComment(form: PurgeComment): Promise<PurgeItemResponse>;
    private buildFullUrl;
    private wrapper;
}
