import { Option } from "@sniptt/monads";
import "reflect-metadata";
import { CommentSortType, ListingType } from "../others";
import { CommentReportView, CommentView } from "../views";
export declare class CreateComment {
    content: string;
    parent_id: Option<number>;
    post_id: number;
    /**
     * An optional front end ID, to tell which is comment is coming back.
     */
    form_id: Option<string>;
    auth: string;
    constructor(init: CreateComment);
}
export declare class EditComment {
    comment_id: number;
    content: Option<string>;
    /**
     * "Distinguishes" a comment, or speak officially. Only doable by community mods or admins.
     */
    distinguished: Option<boolean>;
    /**
     * An optional front end ID, to tell which is comment is coming back.
     */
    form_id: Option<string>;
    auth: string;
    constructor(init: EditComment);
}
/**
 * Only the creator can delete the comment.
 */
export declare class DeleteComment {
    comment_id: number;
    deleted: boolean;
    auth: string;
    constructor(init: DeleteComment);
}
/**
 * Only a mod or admin can remove the comment.
 */
export declare class RemoveComment {
    comment_id: number;
    removed: boolean;
    reason: Option<string>;
    auth: string;
    constructor(init: RemoveComment);
}
export declare class SaveComment {
    comment_id: number;
    save: boolean;
    auth: string;
    constructor(init: SaveComment);
}
export declare class CommentResponse {
    comment_view: CommentView;
    recipient_ids: number[];
    /**
     * An optional front end ID, to tell which is comment is coming back.
     */
    form_id: Option<string>;
}
export declare class CreateCommentLike {
    comment_id: number;
    score: number;
    auth: string;
    constructor(init: CreateCommentLike);
}
/**
 * Comment listing types are `All, Subscribed, Community`
 *
 * You can use either `community_id` or `community_name` as an id.
 * To get posts for a federated community by name, use `name@instance.tld` .
 */
export declare class GetComments {
    type_: Option<ListingType>;
    sort: Option<CommentSortType>;
    max_depth: Option<number>;
    page: Option<number>;
    limit: Option<number>;
    community_id: Option<number>;
    community_name: Option<string>;
    post_id: Option<number>;
    parent_id: Option<number>;
    saved_only: Option<boolean>;
    auth: Option<string>;
    constructor(init: GetComments);
}
export declare class GetCommentsResponse {
    comments: CommentView[];
}
export declare class CreateCommentReport {
    comment_id: number;
    reason: string;
    auth: string;
    constructor(init: CreateCommentReport);
}
export declare class CommentReportResponse {
    comment_report_view: CommentReportView;
}
export declare class ResolveCommentReport {
    report_id: number;
    /**
     * Either resolve or unresolve a report.
     */
    resolved: boolean;
    auth: string;
    constructor(init: ResolveCommentReport);
}
export declare class ListCommentReports {
    page: Option<number>;
    limit: Option<number>;
    /**
     * if no community is given, it returns reports for all communities moderated by the auth user.
     */
    community_id: Option<number>;
    /**
     * Only shows the unresolved reports.
     */
    unresolved_only: Option<boolean>;
    auth: string;
    constructor(init: ListCommentReports);
}
export declare class ListCommentReportsResponse {
    comment_reports: CommentReportView[];
}
