import { Option } from "@sniptt/monads";
import "reflect-metadata";
import { ListingType, SortType } from "../others";
import { Site } from "../source";
import { CommunityModeratorView, CommunityView, PersonViewSafe } from "../views";
/**
 * You can use either `id` or `name` as an id.
 *
 * To get a federated community by name, use `name@instance.tld` .
 */
export declare class GetCommunity {
    id: Option<number>;
    name: Option<string>;
    auth: Option<string>;
    constructor(init: GetCommunity);
}
export declare class GetCommunityResponse {
    community_view: CommunityView;
    site: Option<Site>;
    moderators: CommunityModeratorView[];
    online: number;
}
export declare class CreateCommunity {
    name: string;
    title: string;
    description: Option<string>;
    icon: Option<string>;
    banner: Option<string>;
    nsfw: Option<boolean>;
    posting_restricted_to_mods: Option<boolean>;
    auth: string;
    constructor(init: CreateCommunity);
}
export declare class CommunityResponse {
    community_view: CommunityView;
}
export declare class ListCommunities {
    type_: Option<ListingType>;
    sort: Option<SortType>;
    page: Option<number>;
    limit: Option<number>;
    auth: Option<string>;
    constructor(init: ListCommunities);
}
export declare class ListCommunitiesResponse {
    communities: CommunityView[];
}
export declare class BanFromCommunity {
    community_id: number;
    person_id: number;
    ban: boolean;
    /**
     * Removes/Restores their comments and posts for that community.
     */
    remove_data: Option<boolean>;
    reason: Option<string>;
    /**
     * The expire time in Unix seconds
     */
    expires: Option<number>;
    auth: string;
    constructor(init: BanFromCommunity);
}
export declare class BanFromCommunityResponse {
    person_view: PersonViewSafe;
    banned: boolean;
}
export declare class AddModToCommunity {
    community_id: number;
    person_id: number;
    added: boolean;
    auth: string;
    constructor(init: AddModToCommunity);
}
export declare class AddModToCommunityResponse {
    moderators: CommunityModeratorView[];
}
/**
 * Only mods can edit a community.
 */
export declare class EditCommunity {
    community_id: number;
    title: Option<string>;
    description: Option<string>;
    icon: Option<string>;
    banner: Option<string>;
    nsfw: Option<boolean>;
    posting_restricted_to_mods: Option<boolean>;
    auth: string;
    constructor(init: EditCommunity);
}
export declare class DeleteCommunity {
    community_id: number;
    deleted: boolean;
    auth: string;
    constructor(init: DeleteCommunity);
}
/**
 * Only admins can remove a community.
 */
export declare class RemoveCommunity {
    community_id: number;
    removed: boolean;
    reason: Option<string>;
    /**
     * The expire time in Unix seconds
     */
    expires: Option<number>;
    auth: string;
    constructor(init: RemoveCommunity);
}
export declare class FollowCommunity {
    community_id: number;
    follow: boolean;
    auth: string;
    constructor(init: FollowCommunity);
}
export declare class TransferCommunity {
    community_id: number;
    person_id: number;
    auth: string;
    constructor(init: TransferCommunity);
}
export declare class BlockCommunity {
    community_id: number;
    block: boolean;
    auth: string;
    constructor(init: BlockCommunity);
}
export declare class BlockCommunityResponse {
    community_view: CommunityView;
    blocked: boolean;
}
