import { Option } from "@sniptt/monads";
import "reflect-metadata";
import { CommentSortType, SortType } from "../others";
import { CommentReplyView, CommentView, CommunityModeratorView, PersonMentionView, PersonViewSafe, PostView, PrivateMessageView } from "../views";
export declare class Login {
    username_or_email: string;
    password: string;
    constructor(init: Login);
}
/**
 * Register a new user.
 *
 * Only the first user to register will be able to be the admin.
 */
export declare class Register {
    username: string;
    /**
     * Email is mandatory if email verification is enabled on the server
     */
    email: Option<string>;
    password: string;
    password_verify: string;
    show_nsfw: boolean;
    /**
     * Captcha is only checked if these are enabled in the server.
     */
    captcha_uuid: Option<string>;
    captcha_answer: Option<string>;
    honeypot: Option<string>;
    /**
     * An answer is mandatory if require application is enabled on the server
     */
    answer: Option<string>;
    constructor(init: Register);
}
export declare class GetCaptcha {
}
export declare class GetCaptchaResponse {
    /**
     * Will be undefined if captchas are disabled.
     */
    ok: Option<CaptchaResponse>;
}
export declare class CaptchaResponse {
    /**
     * A Base64 encoded png.
     */
    png: string;
    /**
     * A Base64 encoded wav file.
     */
    wav: Option<string>;
    /**
     * A UUID to match the one given on request.
     */
    uuid: string;
}
export declare class SaveUserSettings {
    show_nsfw: Option<boolean>;
    /**
     * Default for this is `browser`.
     */
    theme: Option<string>;
    /**
     * The [[SortType]].
     *
     * The Sort types from above, zero indexed as a number
     */
    default_sort_type: Option<number>;
    /**
     * The [[ListingType]].
     *
     * Post listing types are `All, Subscribed, Community`
     */
    default_listing_type: Option<number>;
    lang: Option<string>;
    avatar: Option<string>;
    banner: Option<string>;
    display_name: Option<string>;
    email: Option<string>;
    bio: Option<string>;
    matrix_user_id: Option<string>;
    show_avatars: Option<boolean>;
    show_scores: Option<boolean>;
    send_notifications_to_email: Option<boolean>;
    bot_account: Option<boolean>;
    show_bot_accounts: Option<boolean>;
    show_read_posts: Option<boolean>;
    show_new_post_notifs: Option<boolean>;
    auth: string;
    constructor(init: SaveUserSettings);
}
export declare class ChangePassword {
    new_password: string;
    new_password_verify: string;
    old_password: string;
    auth: string;
    constructor(init: ChangePassword);
}
/**
 * The `jwt` string should be stored and used anywhere `auth` is called for.
 */
export declare class LoginResponse {
    /**
     * This is None in response to `Register` if email verification is enabled, or the server requires registration applications.
     */
    jwt: Option<string>;
    verify_email_sent: boolean;
    registration_created: boolean;
}
export declare class GetPersonDetails {
    person_id: Option<number>;
    /**
     * To get details for a federated user, use `person@instance.tld`.
     */
    username: Option<string>;
    sort: Option<SortType>;
    page: Option<number>;
    limit: Option<number>;
    community_id: Option<number>;
    saved_only: Option<boolean>;
    auth: Option<string>;
    constructor(init: GetPersonDetails);
}
export declare class GetPersonDetailsResponse {
    person_view: PersonViewSafe;
    comments: CommentView[];
    posts: PostView[];
    moderates: CommunityModeratorView[];
}
export declare class GetRepliesResponse {
    replies: CommentReplyView[];
}
export declare class GetPersonMentionsResponse {
    mentions: PersonMentionView[];
}
export declare class MarkAllAsRead {
    auth: string;
    constructor(auth: string);
}
export declare class AddAdmin {
    person_id: number;
    added: boolean;
    auth: string;
    constructor(init: AddAdmin);
}
export declare class AddAdminResponse {
    admins: PersonViewSafe[];
}
export declare class BanPerson {
    person_id: number;
    ban: boolean;
    /**
     * Removes/Restores their comments, posts, and communities
     */
    remove_data: Option<boolean>;
    reason: Option<string>;
    /**
     * The expire time in Unix seconds
     */
    expires: Option<number>;
    auth: string;
    constructor(init: BanPerson);
}
export declare class BanPersonResponse {
    person_view: PersonViewSafe;
    banned: boolean;
}
export declare class GetReplies {
    sort: Option<CommentSortType>;
    page: Option<number>;
    limit: Option<number>;
    unread_only: Option<boolean>;
    auth: string;
    constructor(init: GetReplies);
}
export declare class GetPersonMentions {
    sort: Option<CommentSortType>;
    page: Option<number>;
    limit: Option<number>;
    unread_only: Option<boolean>;
    auth: string;
    constructor(init: GetPersonMentions);
}
export declare class MarkPersonMentionAsRead {
    person_mention_id: number;
    read: boolean;
    auth: string;
    constructor(init: MarkPersonMentionAsRead);
}
export declare class PersonMentionResponse {
    person_mention_view: PersonMentionView;
}
export declare class MarkCommentReplyAsRead {
    comment_reply_id: number;
    read: boolean;
    auth: string;
    constructor(init: MarkCommentReplyAsRead);
}
export declare class CommentReplyResponse {
    comment_reply_view: CommentReplyView;
}
/**
 * Permanently deletes your posts and comments
 */
export declare class DeleteAccount {
    password: string;
    auth: string;
    constructor(init: DeleteAccount);
}
export declare class DeleteAccountResponse {
}
export declare class PasswordReset {
    email: string;
    constructor(init: PasswordReset);
}
export declare class PasswordResetResponse {
}
export declare class PasswordChange {
    token: string;
    password: string;
    password_verify: string;
    constructor(init: PasswordChange);
}
export declare class CreatePrivateMessage {
    content: string;
    recipient_id: number;
    auth: string;
    constructor(init: CreatePrivateMessage);
}
export declare class EditPrivateMessage {
    private_message_id: number;
    content: string;
    auth: string;
    constructor(init: EditPrivateMessage);
}
export declare class DeletePrivateMessage {
    private_message_id: number;
    deleted: boolean;
    auth: string;
    constructor(init: DeletePrivateMessage);
}
export declare class MarkPrivateMessageAsRead {
    private_message_id: number;
    read: boolean;
    auth: string;
    constructor(init: MarkPrivateMessageAsRead);
}
export declare class GetPrivateMessages {
    unread_only: Option<boolean>;
    page: Option<number>;
    limit: Option<number>;
    auth: string;
    constructor(init: GetPrivateMessages);
}
export declare class PrivateMessagesResponse {
    private_messages: PrivateMessageView[];
}
export declare class PrivateMessageResponse {
    private_message_view: PrivateMessageView;
}
export declare class GetReportCount {
    /**
     * If a community is supplied, returns the report count for only that community, otherwise returns the report count for all communities the user moderates.
     */
    community_id: Option<number>;
    auth: string;
    constructor(init: GetReportCount);
}
export declare class GetReportCountResponse {
    community_id: Option<number>;
    comment_reports: number;
    post_reports: number;
}
export declare class GetUnreadCount {
    auth: string;
    constructor(init: GetUnreadCount);
}
export declare class GetUnreadCountResponse {
    replies: number;
    mentions: number;
    private_messages: number;
}
export declare class VerifyEmail {
    token: string;
    constructor(init: VerifyEmail);
}
export declare class VerifyEmailResponse {
}
export declare class BlockPerson {
    person_id: number;
    block: boolean;
    auth: string;
    constructor(init: BlockPerson);
}
export declare class BlockPersonResponse {
    person_view: PersonViewSafe;
    blocked: boolean;
}
export declare class GetBannedPersons {
    auth: string;
    constructor(init: GetBannedPersons);
}
export declare class BannedPersonsResponse {
    banned: PersonViewSafe[];
}
