import { Option } from "@sniptt/monads";
import "reflect-metadata";
import { ListingType, SiteMetadata, SortType } from "../others";
import { CommunityModeratorView, CommunityView, PostReportView, PostView } from "../views";
export declare class CreatePost {
    name: string;
    url: Option<string>;
    body: Option<string>;
    nsfw: Option<boolean>;
    community_id: number;
    honeypot: Option<string>;
    auth: string;
    constructor(init: CreatePost);
}
export declare class PostResponse {
    post_view: PostView;
}
export declare class GetPost {
    id: Option<number>;
    comment_id: Option<number>;
    auth: Option<string>;
    constructor(init: GetPost);
}
export declare class GetPostResponse {
    post_view: PostView;
    community_view: CommunityView;
    moderators: CommunityModeratorView[];
    online: number;
}
export declare class GetPosts {
    type_: Option<ListingType>;
    sort: Option<SortType>;
    page: Option<number>;
    limit: Option<number>;
    community_id: Option<number>;
    /**
     * To get posts for a federated community by name, use `name@instance.tld` .
     */
    community_name: Option<string>;
    saved_only: Option<boolean>;
    auth: Option<string>;
    constructor(init: GetPosts);
}
export declare class GetPostsResponse {
    posts: PostView[];
}
export declare class CreatePostLike {
    post_id: number;
    /**
     * `score` can be 0, -1, or 1. Anything else will be rejected.
     */
    score: number;
    auth: string;
    constructor(init: CreatePostLike);
}
export declare class EditPost {
    post_id: number;
    name: Option<string>;
    url: Option<string>;
    body: Option<string>;
    nsfw: Option<boolean>;
    auth: string;
    constructor(init: EditPost);
}
export declare class DeletePost {
    post_id: number;
    deleted: boolean;
    auth: string;
    constructor(init: DeletePost);
}
/**
 * Only admins and mods can remove a post.
 */
export declare class RemovePost {
    post_id: number;
    removed: boolean;
    reason: Option<string>;
    auth: string;
    constructor(init: RemovePost);
}
/**
 * Marks a post as read.
 */
export declare class MarkPostAsRead {
    post_id: number;
    read: boolean;
    auth: string;
    constructor(init: MarkPostAsRead);
}
/**
 * Only admins and mods can lock a post.
 */
export declare class LockPost {
    post_id: number;
    locked: boolean;
    auth: string;
    constructor(init: LockPost);
}
/**
 * Only admins and mods can sticky a post.
 */
export declare class StickyPost {
    post_id: number;
    stickied: boolean;
    auth: string;
    constructor(init: StickyPost);
}
export declare class SavePost {
    post_id: number;
    save: boolean;
    auth: string;
    constructor(init: SavePost);
}
export declare class CreatePostReport {
    post_id: number;
    reason: string;
    auth: string;
    constructor(init: CreatePostReport);
}
export declare class PostReportResponse {
    post_report_view: PostReportView;
}
export declare class ResolvePostReport {
    report_id: number;
    /**
     * Either resolve or unresolve a report.
     */
    resolved: boolean;
    auth: string;
    constructor(init: ResolvePostReport);
}
export declare class ListPostReports {
    page: Option<number>;
    limit: Option<number>;
    /**
     * if no community is given, it returns reports for all communities moderated by the auth user.
     */
    community_id: Option<number>;
    /**
     * Only shows the unresolved reports.
     */
    unresolved_only: Option<boolean>;
    auth: string;
    constructor(init: ListPostReports);
}
export declare class ListPostReportsResponse {
    post_reports: PostReportView[];
}
export declare class GetSiteMetadata {
    url: string;
    constructor(init: GetSiteMetadata);
}
export declare class GetSiteMetadataResponse {
    metadata: SiteMetadata;
}
