import { Option } from "@sniptt/monads";
import "reflect-metadata";
import { ListingType, SearchType, SortType, ModlogActionType } from "../others";
import { AdminPurgeCommentView, AdminPurgeCommunityView, AdminPurgePersonView, AdminPurgePostView, CommentView, CommunityBlockView, CommunityFollowerView, CommunityModeratorView, CommunityView, LocalUserSettingsView, ModAddCommunityView, ModAddView, ModBanFromCommunityView, ModBanView, ModLockPostView, ModRemoveCommentView, ModRemoveCommunityView, ModRemovePostView, ModStickyPostView, ModTransferCommunityView, PersonBlockView, PersonViewSafe, PostView, RegistrationApplicationView, SiteView } from "../views";
/**
 * Search lemmy for different types of data.
 */
export declare class Search {
    /**
     * The search query string.
     */
    q: string;
    type_: Option<SearchType>;
    community_id: Option<number>;
    community_name: Option<string>;
    creator_id: Option<number>;
    sort: Option<SortType>;
    listing_type: Option<ListingType>;
    page: Option<number>;
    limit: Option<number>;
    auth: Option<string>;
    constructor(init: Search);
}
export declare class SearchResponse {
    /**
     * The [[SearchType]].
     */
    type_: string;
    comments: CommentView[];
    posts: PostView[];
    communities: CommunityView[];
    users: PersonViewSafe[];
}
export declare class GetModlog {
    mod_person_id: Option<number>;
    community_id: Option<number>;
    page: Option<number>;
    limit: Option<number>;
    auth: Option<string>;
    type_: ModlogActionType;
    other_person_id: Option<number>;
    constructor(init: GetModlog);
}
export declare class GetModlogResponse {
    removed_posts: ModRemovePostView[];
    locked_posts: ModLockPostView[];
    stickied_posts: ModStickyPostView[];
    removed_comments: ModRemoveCommentView[];
    removed_communities: ModRemoveCommunityView[];
    banned_from_community: ModBanFromCommunityView[];
    banned: ModBanView[];
    added_to_community: ModAddCommunityView[];
    transferred_to_community: ModTransferCommunityView[];
    added: ModAddView[];
    admin_purged_persons: AdminPurgePersonView[];
    admin_purged_communities: AdminPurgeCommunityView[];
    admin_purged_posts: AdminPurgePostView[];
    admin_purged_comments: AdminPurgeCommentView[];
}
export declare class CreateSite {
    name: string;
    sidebar: Option<string>;
    description: Option<string>;
    icon: Option<string>;
    banner: Option<string>;
    enable_downvotes: Option<boolean>;
    open_registration: Option<boolean>;
    enable_nsfw: Option<boolean>;
    community_creation_admin_only: Option<boolean>;
    require_email_verification: Option<boolean>;
    require_application: Option<boolean>;
    application_question: Option<string>;
    private_instance: Option<boolean>;
    default_theme: Option<string>;
    default_post_listing_type: Option<string>;
    hide_modlog_mod_names: Option<boolean>;
    auth: string;
    constructor(init: CreateSite);
}
export declare class EditSite {
    name: Option<string>;
    sidebar: Option<string>;
    description: Option<string>;
    icon: Option<string>;
    banner: Option<string>;
    enable_downvotes: Option<boolean>;
    open_registration: Option<boolean>;
    enable_nsfw: Option<boolean>;
    community_creation_admin_only: Option<boolean>;
    require_email_verification: Option<boolean>;
    require_application: Option<boolean>;
    application_question: Option<string>;
    private_instance: Option<boolean>;
    default_theme: Option<string>;
    legal_information: Option<string>;
    default_post_listing_type: Option<string>;
    hide_modlog_mod_names: Option<boolean>;
    auth: string;
    constructor(init: EditSite);
}
export declare class GetSite {
    auth: Option<string>;
    constructor(init: GetSite);
}
export declare class SiteResponse {
    site_view: SiteView;
}
export declare class GetSiteResponse {
    /**
     * Optional, because the site might not be set up yet.
     */
    site_view: Option<SiteView>;
    admins: PersonViewSafe[];
    online: number;
    version: string;
    /**
     * If you're logged in, you'll get back extra user info.
     */
    my_user: Option<MyUserInfo>;
    federated_instances: Option<FederatedInstances>;
}
/**
 * Your user info, such as blocks, follows, etc.
 */
export declare class MyUserInfo {
    local_user_view: LocalUserSettingsView;
    follows: CommunityFollowerView[];
    moderates: CommunityModeratorView[];
    community_blocks: CommunityBlockView[];
    person_blocks: PersonBlockView[];
}
export declare class LeaveAdmin {
    auth: string;
    constructor(init: LeaveAdmin);
}
export declare class FederatedInstances {
    linked: string[];
    allowed: Option<string[]>;
    blocked: Option<string[]>;
    constructor(init: FederatedInstances);
}
export declare class ResolveObject {
    q: string;
    auth: Option<string>;
    constructor(init: ResolveObject);
}
export declare class ResolveObjectResponse {
    comment: Option<CommentView>;
    post: Option<PostView>;
    community: Option<CommunityView>;
    person: Option<PersonViewSafe>;
}
export declare class PurgePerson {
    person_id: number;
    reason: Option<string>;
    auth: string;
    constructor(init: PurgePerson);
}
export declare class PurgeCommunity {
    community_id: number;
    reason: Option<string>;
    auth: string;
    constructor(init: PurgeCommunity);
}
export declare class PurgePost {
    post_id: number;
    reason: Option<string>;
    auth: string;
    constructor(init: PurgePost);
}
export declare class PurgeComment {
    comment_id: number;
    reason: Option<string>;
    auth: string;
    constructor(init: PurgeComment);
}
export declare class PurgeItemResponse {
    success: boolean;
}
export declare class ListRegistrationApplications {
    /**
     * Only shows the unread applications (IE those without an admin actor)
     */
    unread_only: Option<boolean>;
    page: Option<number>;
    limit: Option<number>;
    auth: string;
    constructor(init: ListRegistrationApplications);
}
export declare class ListRegistrationApplicationsResponse {
    registration_applications: RegistrationApplicationView[];
}
export declare class ApproveRegistrationApplication {
    id: number;
    approve: boolean;
    deny_reason: Option<string>;
    auth: string;
    constructor(init: ApproveRegistrationApplication);
}
export declare class RegistrationApplicationResponse {
    registration_application: RegistrationApplicationView;
}
export declare class GetUnreadRegistrationApplicationCount {
    auth: string;
    constructor(init: GetUnreadRegistrationApplicationCount);
}
export declare class GetUnreadRegistrationApplicationCountResponse {
    registration_applications: number;
}
