import { Option } from "@sniptt/monads";
export declare const VERSION = "v3";
/**
 * All of the websocket operations available.
 */
export declare enum UserOperation {
    Login = 0,
    Register = 1,
    GetCaptcha = 2,
    CreateCommunity = 3,
    CreatePost = 4,
    ListCommunities = 5,
    GetPost = 6,
    GetCommunity = 7,
    CreateComment = 8,
    EditComment = 9,
    DeleteComment = 10,
    RemoveComment = 11,
    SaveComment = 12,
    CreateCommentLike = 13,
    GetPosts = 14,
    CreatePostLike = 15,
    EditPost = 16,
    DeletePost = 17,
    RemovePost = 18,
    LockPost = 19,
    StickyPost = 20,
    MarkPostAsRead = 21,
    SavePost = 22,
    EditCommunity = 23,
    DeleteCommunity = 24,
    RemoveCommunity = 25,
    FollowCommunity = 26,
    GetPersonDetails = 27,
    GetReplies = 28,
    GetPersonMentions = 29,
    MarkPersonMentionAsRead = 30,
    MarkCommentReplyAsRead = 31,
    GetModlog = 32,
    BanFromCommunity = 33,
    AddModToCommunity = 34,
    CreateSite = 35,
    EditSite = 36,
    GetSite = 37,
    AddAdmin = 38,
    GetUnreadRegistrationApplicationCount = 39,
    ListRegistrationApplications = 40,
    ApproveRegistrationApplication = 41,
    BanPerson = 42,
    GetBannedPersons = 43,
    Search = 44,
    ResolveObject = 45,
    MarkAllAsRead = 46,
    SaveUserSettings = 47,
    TransferCommunity = 48,
    LeaveAdmin = 49,
    DeleteAccount = 50,
    PasswordReset = 51,
    PasswordChange = 52,
    CreatePrivateMessage = 53,
    EditPrivateMessage = 54,
    DeletePrivateMessage = 55,
    MarkPrivateMessageAsRead = 56,
    GetPrivateMessages = 57,
    UserJoin = 58,
    GetComments = 59,
    PostJoin = 60,
    CommunityJoin = 61,
    ChangePassword = 62,
    GetSiteMetadata = 63,
    BlockCommunity = 64,
    BlockPerson = 65,
    PurgePerson = 66,
    PurgeCommunity = 67,
    PurgePost = 68,
    PurgeComment = 69,
    CreateCommentReport = 70,
    ResolveCommentReport = 71,
    ListCommentReports = 72,
    CreatePostReport = 73,
    ResolvePostReport = 74,
    ListPostReports = 75,
    GetReportCount = 76,
    GetUnreadCount = 77,
    VerifyEmail = 78
}
/**
 * Different post sort types used in lemmy.
 */
export declare enum SortType {
    /**
     * Posts sorted by hot, but bumped by new comments up to 2 days
     */
    Active = "Active",
    /**
     * Posts sorted by a decaying rank.
     */
    Hot = "Hot",
    /**
     * Posts sorted by the published time.
     */
    New = "New",
    /**
     * Posts sorted by the published time ascending
     */
    Old = "Old",
    /**
     * The top posts for this last day.
     */
    TopDay = "TopDay",
    /**
     * The top posts for this last week.
     */
    TopWeek = "TopWeek",
    /**
     * The top posts for this last month.
     */
    TopMonth = "TopMonth",
    /**
     * The top posts for this last year.
     */
    TopYear = "TopYear",
    /**
     * The top posts of all time.
     */
    TopAll = "TopAll",
    /**
     * Posts sorted by the most comments.
     */
    MostComments = "MostComments",
    /**
     * Posts sorted by the newest comments, with no necrobumping. IE a forum sort.
     */
    NewComments = "NewComments"
}
/**
 * Different comment sort types used in lemmy.
 */
export declare enum CommentSortType {
    /**
     * Comments sorted by a decaying rank.
     */
    Hot = "Hot",
    /**
     * Comments sorted by top score.
     */
    Top = "Top",
    /**
     * Comments sorted by new.
     */
    New = "New",
    /**
     * Comments sorted by old.
     */
    Old = "Old"
}
/**
 * The different listing types for post and comment fetches.
 */
export declare enum ListingType {
    All = "All",
    Local = "Local",
    Subscribed = "Subscribed",
    Community = "Community"
}
/**
 * Search types for lemmy's search.
 */
export declare enum SearchType {
    All = "All",
    Comments = "Comments",
    Posts = "Posts",
    Communities = "Communities",
    Users = "Users",
    Url = "Url"
}
/**
 * Mod log action types
 */
export declare enum ModlogActionType {
    All = "All",
    ModRemovePost = "ModRemovePost",
    ModLockPost = "ModLockPost",
    ModStickyPost = "ModStickyPost",
    ModRemoveComment = "ModRemoveComment",
    ModRemoveCommunity = "ModRemoveCommunity",
    ModBanFromCommunity = "ModBanFromCommunity",
    ModAddCommunity = "ModAddCommunity",
    ModTransferCommunity = "ModTransferCommunity",
    ModAdd = "ModAdd",
    ModBan = "ModBan",
    ModHideCommunity = "ModHideCommunity",
    AdminPurgePerson = "AdminPurgePerson",
    AdminPurgeCommunity = "AdminPurgeCommunity",
    AdminPurgePost = "AdminPurgePost",
    AdminPurgeComment = "AdminPurgeComment"
}
/**
 * Different Subscribed states
 */
export declare enum SubscribedType {
    Subscribed = "Subscribed",
    NotSubscribed = "NotSubscribed",
    Pending = "Pending"
}
/**
 * A holder for a site's metadata ( such as opengraph tags ), used for post links.
 */
export declare class SiteMetadata {
    title: Option<string>;
    description: Option<string>;
    image: Option<string>;
    html: Option<string>;
    constructor(init: SiteMetadata);
}
