import { Option } from "@sniptt/monads";
export declare class LocalUserSettings {
    id: number;
    person_id: number;
    email: Option<string>;
    show_nsfw: boolean;
    theme: string;
    default_sort_type: number;
    default_listing_type: number;
    lang: string;
    show_avatars: boolean;
    send_notifications_to_email: boolean;
    show_bot_accounts: boolean;
    show_scores: boolean;
    show_read_posts: boolean;
    show_new_post_notifs: boolean;
    email_verified: boolean;
    accepted_application: boolean;
}
export declare class PersonSafe {
    id: number;
    name: string;
    display_name: Option<string>;
    avatar: Option<string>;
    banned: boolean;
    published: string;
    updated: Option<string>;
    actor_id: string;
    bio: Option<string>;
    local: boolean;
    banner: Option<string>;
    deleted: boolean;
    inbox_url: string;
    shared_inbox_url: string;
    matrix_user_id: Option<string>;
    admin: boolean;
    bot_account: boolean;
    ban_expires: Option<string>;
}
export declare class Site {
    id: number;
    name: string;
    sidebar: Option<string>;
    published: string;
    updated: Option<string>;
    enable_downvotes: boolean;
    open_registration: boolean;
    enable_nsfw: boolean;
    icon: Option<string>;
    banner: Option<string>;
    description: Option<string>;
    community_creation_admin_only: boolean;
    require_email_verification: boolean;
    require_application: boolean;
    application_question: Option<string>;
    private_instance: boolean;
    default_theme: string;
    default_post_listing_type: string;
    actor_id: string;
    last_refreshed_at: string;
    inbox_url: string;
    public_key: string;
    legal_information: Option<string>;
    hide_modlog_mod_names: Option<boolean>;
}
export declare class PrivateMessage {
    id: number;
    creator_id: number;
    recipient_id: number;
    content: string;
    deleted: boolean;
    read: boolean;
    published: string;
    updated: Option<string>;
    ap_id: string;
    local: boolean;
}
export declare class PostReport {
    id: number;
    creator_id: number;
    post_id: number;
    original_post_name: string;
    original_post_url: Option<string>;
    original_post_body: Option<string>;
    reason: string;
    resolved: boolean;
    resolver_id: Option<number>;
    published: string;
    updated: Option<string>;
}
export declare class Post {
    id: number;
    name: string;
    url: Option<string>;
    body: Option<string>;
    creator_id: number;
    community_id: number;
    removed: boolean;
    locked: boolean;
    published: string;
    updated: Option<string>;
    deleted: boolean;
    nsfw: boolean;
    stickied: boolean;
    embed_title: Option<string>;
    embed_description: Option<string>;
    embed_html: Option<string>;
    thumbnail_url: Option<string>;
    ap_id: string;
    local: boolean;
}
export declare class PasswordResetRequest {
    id: number;
    local_user_id: number;
    token_encrypted: string;
    published: string;
}
export declare class ModRemovePost {
    id: number;
    mod_person_id: number;
    post_id: number;
    reason: Option<string>;
    removed: Option<boolean>;
    when_: string;
}
export declare class ModLockPost {
    id: number;
    mod_person_id: number;
    post_id: number;
    locked: Option<boolean>;
    when_: string;
}
export declare class ModStickyPost {
    id: number;
    mod_person_id: number;
    post_id: number;
    stickied: Option<boolean>;
    when_: string;
}
export declare class ModRemoveComment {
    id: number;
    mod_person_id: number;
    comment_id: number;
    reason: Option<string>;
    removed: Option<boolean>;
    when_: string;
}
export declare class ModRemoveCommunity {
    id: number;
    mod_person_id: number;
    community_id: number;
    reason: Option<string>;
    removed: Option<boolean>;
    expires: Option<string>;
    when_: string;
}
export declare class ModBanFromCommunity {
    id: number;
    mod_person_id: number;
    other_person_id: number;
    community_id: number;
    reason: Option<string>;
    banned: Option<boolean>;
    expires: Option<string>;
    when_: string;
}
export declare class ModBan {
    id: number;
    mod_person_id: number;
    other_person_id: number;
    reason: Option<string>;
    banned: Option<boolean>;
    expires: Option<string>;
    when_: string;
}
export declare class ModAddCommunity {
    id: number;
    mod_person_id: number;
    other_person_id: number;
    community_id: number;
    removed: Option<boolean>;
    when_: string;
}
export declare class ModTransferCommunity {
    id: number;
    mod_person_id: number;
    other_person_id: number;
    community_id: number;
    removed: Option<boolean>;
    when_: string;
}
export declare class ModAdd {
    id: number;
    mod_person_id: number;
    other_person_id: number;
    removed: Option<boolean>;
    when_: string;
}
export declare class AdminPurgePerson {
    id: number;
    admin_person_id: number;
    reason: Option<string>;
    when_: string;
}
export declare class AdminPurgeCommunity {
    id: number;
    admin_person_id: number;
    reason: Option<string>;
    when_: string;
}
export declare class AdminPurgePost {
    id: number;
    admin_person_id: number;
    community_id: number;
    reason: Option<string>;
    when_: string;
}
export declare class AdminPurgeComment {
    id: number;
    admin_person_id: number;
    post_id: number;
    reason: Option<string>;
    when_: string;
}
export declare class CommunitySafe {
    id: number;
    name: string;
    title: string;
    description: Option<string>;
    removed: boolean;
    published: string;
    updated: Option<string>;
    deleted: boolean;
    nsfw: boolean;
    actor_id: string;
    local: boolean;
    icon: Option<string>;
    banner: Option<string>;
    posting_restricted_to_mods: boolean;
}
export declare class CommentReport {
    id: number;
    creator_id: number;
    comment_id: number;
    original_comment_text: string;
    reason: string;
    resolved: boolean;
    resolver_id: Option<number>;
    published: string;
    updated: Option<string>;
}
export declare class Comment {
    id: number;
    creator_id: number;
    post_id: number;
    content: string;
    removed: boolean;
    published: string;
    updated: Option<string>;
    deleted: boolean;
    ap_id: string;
    local: boolean;
    path: string;
    distinguished: boolean;
}
export declare class PersonMention {
    id: number;
    recipient_id: number;
    comment_id: number;
    read: boolean;
    published: string;
}
export declare class CommentReply {
    id: number;
    recipient_id: number;
    comment_id: number;
    read: boolean;
    published: string;
}
export declare class RegistrationApplication {
    id: number;
    local_user_id: number;
    answer: string;
    admin_id: Option<number>;
    deny_reason: Option<string>;
    published: string;
}
