import { Option } from "@sniptt/monads";
import "reflect-metadata";
import { CommentAggregates, CommunityAggregates, PersonAggregates, PostAggregates, SiteAggregates } from "./aggregates";
import { SubscribedType } from "./others";
import { AdminPurgeComment, AdminPurgeCommunity, AdminPurgePerson, AdminPurgePost, Comment, CommentReply, CommentReport, CommunitySafe, LocalUserSettings, ModAdd, ModAddCommunity, ModBan, ModBanFromCommunity, ModLockPost, ModRemoveComment, ModRemoveCommunity, ModRemovePost, ModStickyPost, ModTransferCommunity, PersonMention, PersonSafe, Post, PostReport, PrivateMessage, RegistrationApplication, Site } from "./source";
export declare class PersonViewSafe {
    person: PersonSafe;
    counts: PersonAggregates;
}
export declare class PersonMentionView {
    person_mention: PersonMention;
    comment: Comment;
    creator: PersonSafe;
    post: Post;
    community: CommunitySafe;
    recipient: PersonSafe;
    counts: CommentAggregates;
    creator_banned_from_community: boolean;
    subscribed: SubscribedType;
    saved: boolean;
    creator_blocked: boolean;
    my_vote: Option<number>;
}
export declare class LocalUserSettingsView {
    local_user: LocalUserSettings;
    person: PersonSafe;
    counts: PersonAggregates;
}
export declare class SiteView {
    site: Site;
    counts: SiteAggregates;
}
export declare class PrivateMessageView {
    private_message: PrivateMessage;
    creator: PersonSafe;
    recipient: PersonSafe;
}
export declare class PostView {
    post: Post;
    creator: PersonSafe;
    community: CommunitySafe;
    creator_banned_from_community: boolean;
    counts: PostAggregates;
    subscribed: SubscribedType;
    saved: boolean;
    read: boolean;
    creator_blocked: boolean;
    my_vote: Option<number>;
}
export declare class PostReportView {
    post_report: PostReport;
    post: Post;
    community: CommunitySafe;
    creator: PersonSafe;
    post_creator: PersonSafe;
    creator_banned_from_community: boolean;
    my_vote: Option<number>;
    counts: PostAggregates;
    resolver: Option<PersonSafe>;
}
export declare class CommentView {
    comment: Comment;
    creator: PersonSafe;
    post: Post;
    community: CommunitySafe;
    counts: CommentAggregates;
    creator_banned_from_community: boolean;
    subscribed: SubscribedType;
    saved: boolean;
    creator_blocked: boolean;
    my_vote: Option<number>;
}
export declare class CommentReplyView {
    comment_reply: CommentReply;
    comment: Comment;
    creator: PersonSafe;
    post: Post;
    community: CommunitySafe;
    recipient: PersonSafe;
    counts: CommentAggregates;
    creator_banned_from_community: boolean;
    subscribed: SubscribedType;
    saved: boolean;
    creator_blocked: boolean;
    my_vote: Option<number>;
}
export declare class CommentReportView {
    comment_report: CommentReport;
    comment: Comment;
    post: Post;
    community: CommunitySafe;
    creator: PersonSafe;
    comment_creator: PersonSafe;
    counts: CommentAggregates;
    creator_banned_from_community: boolean;
    my_vote: Option<number>;
    resolver: Option<PersonSafe>;
}
export declare class ModAddCommunityView {
    mod_add_community: ModAddCommunity;
    moderator: Option<PersonSafe>;
    community: CommunitySafe;
    modded_person: PersonSafe;
}
export declare class ModTransferCommunityView {
    mod_transfer_community: ModTransferCommunity;
    moderator: Option<PersonSafe>;
    community: CommunitySafe;
    modded_person: PersonSafe;
}
export declare class ModAddView {
    mod_add: ModAdd;
    moderator: Option<PersonSafe>;
    modded_person: PersonSafe;
}
export declare class ModBanFromCommunityView {
    mod_ban_from_community: ModBanFromCommunity;
    moderator: Option<PersonSafe>;
    community: CommunitySafe;
    banned_person: PersonSafe;
}
export declare class ModBanView {
    mod_ban: ModBan;
    moderator: Option<PersonSafe>;
    banned_person: PersonSafe;
}
export declare class ModLockPostView {
    mod_lock_post: ModLockPost;
    moderator: Option<PersonSafe>;
    post: Post;
    community: CommunitySafe;
}
export declare class ModRemoveCommentView {
    mod_remove_comment: ModRemoveComment;
    moderator: Option<PersonSafe>;
    comment: Comment;
    commenter: PersonSafe;
    post: Post;
    community: CommunitySafe;
}
export declare class ModRemoveCommunityView {
    mod_remove_community: ModRemoveCommunity;
    moderator: Option<PersonSafe>;
    community: CommunitySafe;
}
export declare class ModRemovePostView {
    mod_remove_post: ModRemovePost;
    moderator: Option<PersonSafe>;
    post: Post;
    community: CommunitySafe;
}
export declare class ModStickyPostView {
    mod_sticky_post: ModStickyPost;
    moderator: Option<PersonSafe>;
    post: Post;
    community: CommunitySafe;
}
export declare class AdminPurgeCommunityView {
    admin_purge_community: AdminPurgeCommunity;
    admin: Option<PersonSafe>;
}
export declare class AdminPurgePersonView {
    admin_purge_person: AdminPurgePerson;
    admin: Option<PersonSafe>;
}
export declare class AdminPurgePostView {
    admin_purge_post: AdminPurgePost;
    admin: Option<PersonSafe>;
    community: CommunitySafe;
}
export declare class AdminPurgeCommentView {
    admin_purge_comment: AdminPurgeComment;
    admin: Option<PersonSafe>;
    post: Post;
}
export declare class CommunityFollowerView {
    community: CommunitySafe;
    follower: PersonSafe;
}
export declare class CommunityBlockView {
    person: PersonSafe;
    community: CommunitySafe;
}
export declare class CommunityModeratorView {
    community: CommunitySafe;
    moderator: PersonSafe;
}
export declare class CommunityPersonBanView {
    community: CommunitySafe;
    person: PersonSafe;
}
export declare class PersonBlockView {
    person: PersonSafe;
    target: PersonSafe;
}
export declare class CommunityView {
    community: CommunitySafe;
    subscribed: SubscribedType;
    blocked: boolean;
    counts: CommunityAggregates;
}
export declare class RegistrationApplicationView {
    registration_application: RegistrationApplication;
    creator_local_user: LocalUserSettings;
    creator: PersonSafe;
    admin: Option<PersonSafe>;
}
export interface CommentNode {
    comment_view: CommentView | PersonMentionView | CommentReplyView;
    children: CommentNode[];
    depth: number;
}
